@@ -1,4 +1,5 @@
 import ast
+import uuid
 import asyncio
 import json
 import os
@@ -244,12 +245,19 @@ def build_dataset(
         total=len(data_frame),
         desc="Building a dataset for uploading safely.",
     ):
-        dedupe_id = "_".join([row[const.CONVERSATION_UUID], row[const.CALL_UUID]])
+        conversation_uuid = row[const.CONVERSATION_UUID]
+        dedupe_id = f"{conversation_uuid}_{uuid.uuid4().hex}"
         errors = []
         if const.RAW in data_frame.columns:
             data = json.loads(row[const.RAW])
         else:
             data = row.to_dict()
+        utterance_columns = {const.UTTERANCES, const.ALTERNATIVES}
+
+        if data_frame.columns.intersection(utterance_columns).empty:
+            raise ValueError(f"Expected one of {const.UTTERANCES} or {const.ALTERNATIVES} "
+            "columns in the dataframe. {data_frame.columns}")
+        utterance_col = const.UTTERANCES if const.UTTERANCES in data_frame.columns else const.ALTERNATIVES
 
         data_point = {
             const.PRIORITY: 1,
@@ -259,7 +267,7 @@ def build_dataset(
                 **data,
                 const.CALL_UUID: str(row[const.CALL_UUID]),
                 const.CONVERSATION_UUID: str(row[const.CONVERSATION_UUID]),
-                const.ALTERNATIVES: extract_utterances_safely(row[const.CONVERSATION_UUID], row[const.UTTERANCES]),
+                const.ALTERNATIVES: extract_utterances_safely(row[const.CONVERSATION_UUID], row[utterance_col]),
             },
             const.IS_GOLD: False,
         }
